@@ -6,16 +6,12 @@
 
 #pragma once
 
-#include <KConfigWatcher>
-
 #include <QObject>
 #include <QRect>
 
 #include <netwm.h>
 #include <qwindowdefs.h>
 
-#include "kactivitymanagerd_plugins_settings.h"
-
 class QAction;
 class QActionGroup;
 class QQuickItem;
@@ -31,7 +27,6 @@ class Backend : public QObject
 {
     Q_OBJECT
 
-    Q_PROPERTY(QQuickItem *taskManagerItem READ taskManagerItem WRITE setTaskManagerItem NOTIFY taskManagerItemChanged)
     Q_PROPERTY(bool highlightWindows READ highlightWindows WRITE setHighlightWindows NOTIFY highlightWindowsChanged)
     Q_PROPERTY(bool windowViewAvailable READ windowViewAvailable NOTIFY windowViewAvailableChanged)
 
@@ -50,9 +45,6 @@ public:
     explicit Backend(QObject *parent = nullptr);
     ~Backend() override;
 
-    QQuickItem *taskManagerItem() const;
-    void setTaskManagerItem(QQuickItem *item);
-
     bool highlightWindows() const;
     void setHighlightWindows(bool highlight);
 
@@ -67,26 +59,18 @@ public:
 
     Q_INVOKABLE bool isApplication(const QUrl &url) const;
 
-    Q_INVOKABLE QList<QUrl> jsonArrayToUrlList(const QJsonArray &array) const;
-
     Q_INVOKABLE void cancelHighlightWindows();
 
     Q_INVOKABLE qint64 parentPid(qint64 pid) const;
 
-    static QUrl tryDecodeApplicationsUrl(const QUrl &launcherUrl);
+    Q_INVOKABLE static QUrl tryDecodeApplicationsUrl(const QUrl &launcherUrl);
     Q_INVOKABLE static QStringList applicationCategories(const QUrl &launcherUrl);
 
-    /**
-     * @return A mimedata map that contains required information to perform a task drag
-     */
-    Q_INVOKABLE static QVariantMap generateMimeData(const QString &mimeType, const QVariant &mimeData, const QUrl &url);
-
 public Q_SLOTS:
     void activateWindowView(const QVariant &winIds);
     void windowsHovered(const QVariant &winIds, bool hovered);
 
 Q_SIGNALS:
-    void taskManagerItemChanged() const;
     void highlightWindowsChanged() const;
     void addLauncher(const QUrl &url) const;
     void windowViewAvailableChanged();
@@ -101,13 +85,9 @@ private:
 
     QVariantList systemSettingsActions(QObject *parent) const;
 
-    QQuickItem *m_taskManagerItem = nullptr;
     bool m_highlightWindows;
     QStringList m_windowsToHighlight;
     QActionGroup *m_actionGroup = nullptr;
     KActivities::Consumer *m_activitiesConsumer = nullptr;
     bool m_windowViewAvailable = false;
-
-    KActivityManagerdPluginsSettings m_activityManagerPluginsSettings;
-    KConfigWatcher::Ptr m_activityManagerPluginsSettingsWatcher;
 };
