@@ -8,16 +8,17 @@
 
 // Qt
 #include <QSortFilterProxyModel>
-#include <QWidgetList> //For WId
 
 // KDE
-#include <KActivities/ActivitiesModel>
-#include <KActivities/Consumer>
-#include <KActivities/Info>
+#include <PlasmaActivities/ActivitiesModel>
+#include <PlasmaActivities/Consumer>
 
-#include <config-X11.h>
+#include <config-X11.h> // Required by files that include this header
 
-#include <netwm.h>
+namespace TaskManager
+{
+class WindowTasksModel;
+}
 
 class SortedActivitiesModel : public QSortFilterProxyModel
 {
@@ -35,6 +36,8 @@ public:
 
     QString relativeActivity(int relative) const;
 
+    TaskManager::WindowTasksModel * const m_windowTasksModel;
+
 protected:
     uint lastUsedTime(const QString &activity) const;
     bool lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const override;
@@ -59,9 +62,9 @@ public Q_SLOTS:
 
     void rowChanged(int row, const QList<int> &roles);
 
-    void onWindowAdded(WId window);
-    void onWindowRemoved(WId window);
-    void onWindowChanged(WId window, NET::Properties properties, NET::Properties2 properties2);
+    void onWindowAdded(const QModelIndex &parent, int first, int last);
+    void onWindowRemoved(const QModelIndex &parent, int first, int last);
+    void onWindowChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles);
 
 Q_SIGNALS:
     void inhibitUpdatesChanged(bool inhibitUpdates);
@@ -74,5 +77,7 @@ private:
     KActivities::ActivitiesModel *m_activitiesModel = nullptr;
     KActivities::Consumer *m_activities = nullptr;
 
-    QHash<QString, QList<WId>> m_activitiesWindows;
+    QHash<QString, QVariantList> m_activitiesWindows;
+
+    QVariant getWinIdList(const QModelIndex &parent, int row);
 };
