@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 #include <QColor>
 #include <QString>
 
@@ -18,7 +18,7 @@ class KeyboardFiltersSettings;
 class ScreenReaderSettings;
 class AccessibilityData;
 
-class KAccessConfig : public KQuickAddons::ManagedConfigModule
+class KAccessConfig : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(MouseSettings *mouseSettings READ mouseSettings CONSTANT)
@@ -36,7 +36,7 @@ class KAccessConfig : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(bool screenReaderIsDefaults READ screenReaderIsDefaults NOTIFY screenReaderIsDefaultsChanged)
 
 public:
-    KAccessConfig(QObject *parent, const KPluginMetaData &, const QVariantList &);
+    KAccessConfig(QObject *parent, const KPluginMetaData &);
     ~KAccessConfig() override;
 
     void save() override;
